@@ -3,7 +3,7 @@ package FlyBy;
 use strict;
 use warnings;
 use 5.010;
-our $VERSION = '0.093';
+our $VERSION = '0.094';
 
 use Moo;
 
@@ -255,7 +255,11 @@ sub all_keys {
 
 sub values_for_key {
     my ($self, $key) = @_;
-    return (sort { $a cmp $b } keys %{$self->index_sets->{$key}});
+
+    my $set = $self->index_sets->{$key};
+    my @values = grep { my $v = $set->{$_}; $v && %{$v->{elements}} } keys %$set;
+
+    return (sort { $a cmp $b } @values);
 }
 
 1;
